[][src]Struct flowrlib::coordinator::Submission

pub struct Submission {
    pub max_parallel_jobs: usize,
    pub job_timeout: Duration,
    pub debug: bool,
    // some fields omitted
}

A Submission is the struct used to send a flow to the Coordinator for execution. It contains all the information necessary to execute it:

A new Submission is created supplying:

  • the manifest of the flow to execute
  • the maximum number of jobs you want dispatched/executing in parallel
  • whether to display some execution metrics when the flow completes
  • an optional DebugClient to allow you to debug the execution

Fields

max_parallel_jobs: usizejob_timeout: Durationdebug: bool

Implementations

impl Submission[src]

pub fn new(
    manifest_url: &str,
    max_parallel_jobs: usize,
    #[cfg(feature = "debugger")] debug: bool
) -> Submission
[src]

Create a new Submission of a Flow for execution with the specified Manifest of Functions, executing it with a maximum of mac_parallel_jobs running in parallel connecting via the optional DebugClient