[][src]Module flowrlib::debug

'debug' defines structs passed between the Server and the Client regarding debug events and client responses to them

Enums

Event

A run-time event that the debugger communicates to the debug_client for it to decide what to do, or what to request of the user

Param

Types of Params used in communications between the debugger and the debug_client

Response

A debugger Response sent by the debug_client to the debug server