[][src]Enum flowrlib::debug::Param

pub enum Param {
    Wildcard,
    Numeric(usize),
    Output((usize, String)),
    Input((usize, usize)),
    Block((usize, usize)),
}

Types of Params used in communications between the debugger and the debug_client

Variants

Wildcard

A "*" style parameter - meaning will depend on the Command it's use with

Numeric(usize)

A positive integer was specified

Output((usize, String))

A descriptor for the Output of a Function was specified

Input((usize, usize))

A descriptor for the Inout of a Function was specified

Block((usize, usize))

A description of a "block" (when one function is blocked from running by another) was specified