[][src]Enum flowrlib::debug::Response

pub enum Response {
    Ack,
    Breakpoint(Option<Param>),
    Continue,
    Delete(Option<Param>),
    EnterDebugger,
    ExitDebugger,
    Inspect,
    List,
    Print(Option<Param>),
    RunReset,
    Step(Option<Param>),
    GetState,
    GetFunctionState(usize),
    Error(String),
    Invalid,
}

A debugger Response sent by the debug_client to the debug server

Variants

Ack

Acknowledge event processed correctly

Breakpoint(Option<Param>)

Set a breakpoint - with an optional parameter

Continue

continue execution of the flow

Delete(Option<Param>)

delete an existing breakpoint - with an optional parameter

EnterDebugger

enter the debugger at the next opportunity the runtime has

ExitDebugger

exit the debugger and runtime

Inspect

inspect the current state

List

list existing breakpoints

Print(Option<Param>)

print a function or functions state

RunReset

reset flow execution back to the initial state

Step(Option<Param>)

step forward in flow execution by executing one (default) or more Jobs

GetState

Get the state of the Flow

GetFunctionState(usize)

Get the state of a specific Function

Error(String)

An error on the client side

Invalid

Invalid - used when deserialization goes wrong