Module debug_command

Module debug_command 

Provides the DebugCommanddebug_command::DebugCommand enum for commands from debug client to debug server

Enums

BreakpointSpec
Types of Params used in communications between the debugger and the debug_client
DebugCommand
A Command sent by the debug_client to the debugger