We’ll put our errors in an errors module, and other modules in this crate will use errors::*;
to get access to everything error_chain creates.
Macros
Exits a function early with an error
Structs
The Error type.
Enums
The kind of an error.
Traits
Additional methods for Result, for easy interaction with this crate.
Type Definitions
Convenient wrapper around std::Result.