Module function
flowrlib
function defines functions that form part of a flow
function
Function contains all the information needed about a fubction and its implementation to be able to execute a flow using it.
Function