pub struct Job {
pub process_id: usize,
pub parent_id: usize,
pub function_name: String,
pub payload: Payload,
pub result: Result<(Option<Value>, RunAgain)>,
pub connections: Vec<OutputConnection>,
}Expand description
A Job contains the information necessary to manage the execution of a function in the
flow on a set of input values, and then where to send the outputs that maybe produces.
Fields
process_id: usizeThe process_id of the function in the RunState’s list of functions that will execute this job
parent_id: usizeThe parent_id of the flow containing the function executing the job
function_name: StringThe function name (for logging without looking up the function)
payload: Payloadthe payload required to execute the job
result: Result<(Option<Value>, RunAgain)>The result of the execution with the job_id, the optional output Value and if the function
should be run again in the future
connections: Vec<OutputConnection>The destinations (other function’s inputs) where any output should be sent