pub struct Payload {
pub job_id: usize,
pub input_set: Vec<Value>,
pub implementation_url: Url,
}Expand description
Conatins the minimum amount of information required to execute a Job and return the result
Fields
job_id: usizeEach Job has a unique id that increments as jobs are executed
input_set: Vec<Value>The set of input values to be used by the function when executing this job
implementation_url: UrlThe url of the implementation to be run for this job