[][src]Module flowrlib::provider

provider is a trait that is implemented to provide content to flowrlib in different environments it runs in

Traits

Provider

A content provider is responsible with interfacing with the environment and doing IO or what is required to supply content related with flows - isolating other libraries from the File SSystem or IO. It must implement the Provider trait