Module run_state

Module run_state 

Provides RunState that tracks the current runtime state, used by Coordinator

Structs

RunState
RunState is a structure that maintains the state of all the functions in the currently executing flow.

Enums

State
State represents the possible states it is possible for a function to be in