State

Enum State 

pub enum State {
    Ready,
    Waiting,
    Running,
    Completed,
}
State represents the possible states it is possible for a function to be in

Variants



Ready

Ready - Function will be in Ready state when all of its inputs are full



Waiting

Waiting - Function is in the Waiting state when at least one of its inputs is not full



Running

Running - Function is in Running state when it has been picked from the Ready list for execution using the next function



Completed

Completed - Function has indicated that it no longer wants to be run, so it’s execution has completed.