[][src]Enum flowrlib::runtime::Event

pub enum Event {
    FlowStart,
    FlowEnd(Metrics),
    Stdout(String),
    Stderr(String),
    GetStdin,
    GetLine,
    GetArgs,
    Write(StringVec<u8>),
    PixelWrite((u32, u32)(u8, u8, u8)(u32, u32)String),
    StdoutEOF,
    StderrEOF,
    Invalid,
}

A run-time Event sent from the run-time to a runtime_client

Variants

FlowStart

A flow has started executing

FlowEnd(Metrics)

A flow has stopped executing

Stdout(String)

A String of contents was sent to stdout

Stderr(String)

A String of contents was sent to stderr

GetStdin

A Request to read from Stdin

GetLine

A Request to read a line of characters from Stdin

GetArgs

A Request to get the arguments for the flow

Write(StringVec<u8>)

A Request to write a series of bytes to a file

PixelWrite((u32, u32)(u8, u8, u8)(u32, u32)String)

A Request to write a pixel to an ImageBuffer

StdoutEOF

A Request to snd EOF to Stdout

StderrEOF

A Request to snd EOF to Stderr

Invalid

Invalid - used when deserialization goes wrong