[][src]Enum flowrlib::runtime::Response

pub enum Response {
    Ack,
    Stdin(String),
    Line(String),
    Args(Vec<String>),
    Error(String),
    GetStdinEOF,
    GetLineEOF,
    ClientExiting,
    ClientSubmission(Submission),
    EnterDebugger,
    Invalid,
}

A Response from the runtime_client to the run-time

Variants

Ack

Simple acknowledgement

Stdin(String)

A String read from Stdin

Line(String)

A line of text read from Stdin using readline

Args(Vec<String>)

A Vector of Strings that are the flow's arguments

Error(String)

An Error occurred in the runtime_client

GetStdinEOF

EOF was detected on input reading using Stdin

GetLineEOF

EOF was detected on input reading Stdin using Readline

ClientExiting

Client is exiting Event loop

ClientSubmission(Submission)

A submission from the client for execution

EnterDebugger

Client requests that server enters the ddebugger at the next opportunity

Invalid

Invalid - used when deserialization goes wrong