[−][src]Enum flowrlib::debug::Event
A run-time event that the debugger communicates to the debug_client for it to decide what to do, or what to request of the user
Variants
A Job ran to completion by a function - includes: job_id, function_id
Entering the debugger
The debugger/run-time is exiting
The run-time is about to send a Job for execution - an opportunity to break
includes: job_id, function_id
A breakpoint on a Block between two functions was encountered
includes: blocked_id, blocking_id, blocking_io_number
A breakpoint on a Value being sent between two functions was encountered
includes: source_process_id, output_route, value, destination_id, input_number));
A panic occurred executing a Flows Job - includes the output of the job that panicked
There was an error executing the Job
Execution of the flow has started
Execution of the flow has ended
Deadlock(String)A check has detected that there is a deadlock between functions impeding more execution
A value is being sent from the output of one function to the input of another includes: source_process_id, value, destination_id, input_number
Error(String)An error was detected - includes: A string describing the error
Message(String)A message for display to the user of the debug_client
The run-time is resetting the status back to the initial state
WaitingForCommand(usize)Debugger is blocked waiting for a command before proceeding
Invalid - used when deserialization goes wrong