[−][src]Enum flowrlib::debug::Param
Types of Params used in communications between the debugger and the debug_client
Variants
A "*" style parameter - meaning will depend on the Command it's use with
Numeric(usize)A positive integer was specified
A descriptor for the Output of a Function was specified
A descriptor for the Inout of a Function was specified
A description of a "block" (when one function is blocked from running by another) was specified