[−][src]Enum flowrlib::debug::Response
A debugger Response sent by the debug_client to the debug server
Variants
Acknowledge event processed correctly
Set a breakpoint - with an optional parameter
continue execution of the flow
delete an existing breakpoint - with an optional parameter
enter the debugger at the next opportunity the runtime has
exit the debugger and runtime
inspect the current state
list existing breakpoints
print a function or functions state
reset flow execution back to the initial state
step forward in flow execution by executing one (default) or more Jobs
Get the state of the Flow
GetFunctionState(usize)Get the state of a specific Function
Error(String)An error on the client side
Invalid - used when deserialization goes wrong