The DebuggerHandler debugger_handler::DebuggerHandler trait defines methods a a client must
implement in order to handle the interaction between a client and the debugger (in the Coordinator)
Traits
- Debugger
Handler [DebugHandler]trait that must be implemented by clients wishing to interface with the debugger