Optional mDNS-SD service discovery helpers Optional mDNS-SD service discovery helpers.
These functions provide a convenient way to advertise and discover flow services
using mDNS-SD. They are not required — other binaries using flowrlib can
implement their own discovery mechanism.
Functions
- discover_
service - Discover a service by name using mDNS-SD. Blocks until the service is found or the default timeout (30 seconds) expires.
- enable_
service_ discovery - Register a service for mDNS-SD discovery.