Provides RunState that tracks the current runtime state, used by Coordinator
Structs
- RunState
RunStateis a structure that maintains the state of all the functions in the currently executing flow.
Enums
- State
Staterepresents the possible states it is possible for a function to be in