[−][src]Enum flowrlib::runtime::Response
A Response from the runtime_client to the run-time
Variants
Simple acknowledgement
Stdin(String)A String read from Stdin
Line(String)A line of text read from Stdin using readline
A Vector of Strings that are the flow's arguments
Error(String)An Error occurred in the runtime_client
EOF was detected on input reading using Stdin
EOF was detected on input reading Stdin using Readline
Client is exiting Event loop
ClientSubmission(Submission)A submission from the client for execution
Client requests that server enters the ddebugger at the next opportunity
Invalid - used when deserialization goes wrong