Module services

Module services 

Provides well-known service names used across multiple binary crates

Constants

CONTROL_SERVICE_NAME
CONTROL_SERVICE_NAME is a control PUB/SUB socket used to control executors that are listening on the JOB_SERVICE and sending results back via the RESULTS_SERVICE
COORDINATOR_SERVICE_NAME
Use this to discover the coordinator service by name
DEBUG_SERVICE_NAME
Use this to discover the debug service by name
FLOW_SERVICE_TYPE
The mDNS service type for flow services
JOB_SERVICE_NAME
JOB_SERVICE_NAME can be used to discover the queue serving jobs for execution
RESULTS_JOB_SERVICE_NAME
RESULTS_JOB_SERVICE_NAME can be used to discover the queue where to send job results