Provides well-known service names used across multiple binary crates
Constants
- CONTROL_
SERVICE_ NAME CONTROL_SERVICE_NAMEis a control PUB/SUB socket used to control executors that are listening on theJOB_SERVICEand sending results back via theRESULTS_SERVICE- COORDINATOR_
SERVICE_ NAME - Use this to discover the coordinator service by name
- DEBUG_
SERVICE_ NAME - Use this to discover the debug service by name
- FLOW_
SERVICE_ TYPE - The mDNS service type for flow services
- JOB_
SERVICE_ NAME JOB_SERVICE_NAMEcan be used to discover the queue serving jobs for execution- RESULTS_
JOB_ SERVICE_ NAME RESULTS_JOB_SERVICE_NAMEcan be used to discover the queue where to send job results